Package 'mitology'

Title: Study of mitochondrial activity from RNA-seq data
Description: mitology allows to study the mitochondrial activity throught high-throughput RNA-seq data. It is based on a collection of genes whose proteins localize in to the mitochondria. From these, mitology provides a reorganization of the pathways related to mitochondria activity from Reactome and Gene Ontology. Further a ready-to-use implementation of MitoCarta3.0 pathways is included.
Authors: Stefania Pirrotta [cre, aut] (ORCID: <https://orcid.org/0009-0004-0030-217X>), Enrica Calura [aut, fnd] (ORCID: <https://orcid.org/0000-0001-8463-2432>)
Maintainer: Stefania Pirrotta <[email protected]>
License: AGPL-3
Version: 1.5.0
Built: 2026-05-09 09:12:14 UTC
Source: https://github.com/bioc/mitology

Help Index


Mitochondrial Enrichment Analysis of a gene list.

Description

Given a vector of genes, this function will return the enrichment analysis for the mitochondrial gene sets after FDR control. For the Reactome, GO-CC and GO-BP databases it returns also the enrichment results for the corresponding original pathways.

Usage

enrichMito(genes, database)

Arguments

genes

a vector of gene ENSEMBL id.

database

character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".

Value

enrichment analysis for the mitochondrial gene sets.

Examples

data(ovse)

Get the mitochondrial gene sets

Description

It returns the mitochondrial gene sets (in form of list or data frame) of the four possible databases: "MitoCarta", "Reactome", "GO-CC" and "GO-BP".

Usage

getGeneSets(
  database = "MitoCarta",
  nametype = "ENSEMBL",
  objectType = "list",
  sections = FALSE
)

Arguments

database

character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".

nametype

character string saying the type of gene name ID. Either one of "SYMBOL", "ENTREZID" or "ENSEMBL".

objectType

character string saying the type of needed object. Either one of "list" or "dataframe".

sections

logical. Either to keep the aggregated gene set categories or the specific gene sets. Default is FALSE.

Value

the mitochondrial gene sets.

Examples

MClist <- getGeneSets()

Mitochondrial GSEA of a gene list.

Description

Gene set enrichment analysis for the mitochondrial gene sets. For the Reactome, GO-CC and GO-BP databases it returns also the GSEA results for the corresponding original pathways.

Usage

gseaMito(genes, database)

Arguments

genes

order ranked gene vector named by ENSEMBL id.

database

character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".

Value

GSEA results for the mitochondrial gene sets.

Examples

data(ovse)

Mitochondrial genes

Description

Here are listed all the final mitochondrial genes in ENSEMBL id, the corresponding SYMBOL id and the database from where they were collected.

Usage

data(MitoGenesDB)

Format

An object of class data.frame with 2996 rows and 3 columns.


Heatmap of mitochondrial gene sets.

Description

Given a matrix of scores, it returns a heatmap of the mitochondrial gene sets.

Usage

mitoHeatmap(
  data,
  database = "MitoCarta",
  sampleAnnot = NULL,
  splitSamples = FALSE,
  splitSections = FALSE,
  ...
)

Arguments

data

matrix or data.frame with samples in columns and mitochondrial gene sets in rows.

database

character string saying the database used for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".

sampleAnnot

character vector with samples' annotation.

splitSamples

logical. If TRUE it splits samples by annotation. sampleAnnot must be provided.

splitSections

logical. If TRUE it splits gene sets by main section.

...

other parameters specific of the function Heatmap.

Value

A Heatmap-class object.

Examples

MClist <- getGeneSets()
n <- length(names(MClist)) * 5
rmatrix <- matrix(rnorm(n, 0), ncol = 5)
rownames(rmatrix) <- names(MClist)
colnames(rmatrix) <- paste0("Sample_", seq_len(5))
mitoHeatmap(data = rmatrix, database = "MitoCarta")

Circular heatmap on mitochondrial gene set tree.

Description

Given a matrix of scores, it returns a circular heatmap of the mitochondrial gene sets (leaf of the database tree) or gene set groups (section of the database tree).

Usage

mitoTreeHeatmap(
  data,
  database = "MitoCarta",
  sections = FALSE,
  samples = NULL,
  labelNames = "sections",
  ...
)

Arguments

data

matrix or data.frame with samples in columns and mitochondrial gene sets in rows.

database

character string saying the database used for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".

sections

logical. Either to keep the aggregated gene set categories or the specific gene sets. Default is FALSE.

samples

character vector with the names of samples to be plotted. Otherwise all samples are plotted.

labelNames

character string that says to plot either the names of "sections" or "leaves".

...

other arguments passed on to the gheatmap function.

Value

A ggplot object.

Examples

MClist <- getGeneSets()
n <- length(names(MClist)) * 5
rmatrix <- matrix(rnorm(n, 0), ncol = 5)
rownames(rmatrix) <- names(MClist)
colnames(rmatrix) <- paste0("Sample_", seq_len(5))
mitoTreeHeatmap(data = rmatrix, database = "MitoCarta")

Circular dotplot on mitochondrial gene set tree.

Description

A circular dotplot of the mitochondrial enrichment results.

Usage

mitoTreePoint(
  data,
  database = "MitoCarta",
  pvalCutoff = 0.05,
  labsize = 3,
  max_point_size = 4,
  color = "p.adjust"
)

Arguments

data

named list of the result from enrichMito or gseaMito.

database

character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".

pvalCutoff

pvalue cutoff to select enriched gene sets

labsize

label size

max_point_size

max point size

color

variable used to color enriched terms, e.g. 'pvalue', 'p.adjust' or 'NES'.

Value

A ggplot object.

Examples

data(ovse)

Example expression data.

Description

This is an example dataset containing gene expression values (in normalized counts) of 40 ovarian cancer (OVC) patients extracted from the Cancer Genome Atlas (TCGA) database. This dataset should be used only with example purpose. RNA sequencing OVC data were retrieved using curatedTCGAData package. Data were then normalized with the betweenLaneNormalization function. To lighten the dataset, the consensusOVSign function was computed, which return 4 different scores, one for each OVC subtype (Chen et al, 2018, Clinical Cancer Research) and the 10 samples with the highest scores were selected for each subgroup. Further, only the mitochondrial genes included in mitology were kept. Finally, the log fold change of the IMR versus the PRO samples were computed. Further details in mitology/inst/scripts/howToGenerateOvse.Rmd.

Usage

data(ovse)

Format

An object of class SummarizedExperiment with 2388 rows and 40 columns.