| Title: | Study of mitochondrial activity from RNA-seq data |
|---|---|
| Description: | mitology allows to study the mitochondrial activity throught high-throughput RNA-seq data. It is based on a collection of genes whose proteins localize in to the mitochondria. From these, mitology provides a reorganization of the pathways related to mitochondria activity from Reactome and Gene Ontology. Further a ready-to-use implementation of MitoCarta3.0 pathways is included. |
| Authors: | Stefania Pirrotta [cre, aut] (ORCID: <https://orcid.org/0009-0004-0030-217X>), Enrica Calura [aut, fnd] (ORCID: <https://orcid.org/0000-0001-8463-2432>) |
| Maintainer: | Stefania Pirrotta <[email protected]> |
| License: | AGPL-3 |
| Version: | 1.5.0 |
| Built: | 2026-05-09 09:12:14 UTC |
| Source: | https://github.com/bioc/mitology |
Given a vector of genes, this function will return the enrichment analysis for the mitochondrial gene sets after FDR control. For the Reactome, GO-CC and GO-BP databases it returns also the enrichment results for the corresponding original pathways.
enrichMito(genes, database)enrichMito(genes, database)
genes |
a vector of gene ENSEMBL id. |
database |
character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP". |
enrichment analysis for the mitochondrial gene sets.
data(ovse)data(ovse)
It returns the mitochondrial gene sets (in form of list or data frame) of the four possible databases: "MitoCarta", "Reactome", "GO-CC" and "GO-BP".
getGeneSets( database = "MitoCarta", nametype = "ENSEMBL", objectType = "list", sections = FALSE )getGeneSets( database = "MitoCarta", nametype = "ENSEMBL", objectType = "list", sections = FALSE )
database |
character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP". |
nametype |
character string saying the type of gene name ID. Either one of "SYMBOL", "ENTREZID" or "ENSEMBL". |
objectType |
character string saying the type of needed object. Either one of "list" or "dataframe". |
sections |
logical. Either to keep the aggregated gene set categories or the specific gene sets. Default is FALSE. |
the mitochondrial gene sets.
MClist <- getGeneSets()MClist <- getGeneSets()
Gene set enrichment analysis for the mitochondrial gene sets. For the Reactome, GO-CC and GO-BP databases it returns also the GSEA results for the corresponding original pathways.
gseaMito(genes, database)gseaMito(genes, database)
genes |
order ranked gene vector named by ENSEMBL id. |
database |
character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP". |
GSEA results for the mitochondrial gene sets.
data(ovse)data(ovse)
Here are listed all the final mitochondrial genes in ENSEMBL id, the corresponding SYMBOL id and the database from where they were collected.
data(MitoGenesDB)data(MitoGenesDB)
An object of class data.frame with 2996 rows and 3 columns.
Given a matrix of scores, it returns a heatmap of the mitochondrial gene sets.
mitoHeatmap( data, database = "MitoCarta", sampleAnnot = NULL, splitSamples = FALSE, splitSections = FALSE, ... )mitoHeatmap( data, database = "MitoCarta", sampleAnnot = NULL, splitSamples = FALSE, splitSections = FALSE, ... )
data |
matrix or data.frame with samples in columns and mitochondrial gene sets in rows. |
database |
character string saying the database used for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP". |
sampleAnnot |
character vector with samples' annotation. |
splitSamples |
logical. If TRUE it splits samples by annotation. sampleAnnot must be provided. |
splitSections |
logical. If TRUE it splits gene sets by main section. |
... |
other parameters specific of the function
|
A Heatmap-class object.
MClist <- getGeneSets() n <- length(names(MClist)) * 5 rmatrix <- matrix(rnorm(n, 0), ncol = 5) rownames(rmatrix) <- names(MClist) colnames(rmatrix) <- paste0("Sample_", seq_len(5)) mitoHeatmap(data = rmatrix, database = "MitoCarta")MClist <- getGeneSets() n <- length(names(MClist)) * 5 rmatrix <- matrix(rnorm(n, 0), ncol = 5) rownames(rmatrix) <- names(MClist) colnames(rmatrix) <- paste0("Sample_", seq_len(5)) mitoHeatmap(data = rmatrix, database = "MitoCarta")
Given a matrix of scores, it returns a circular heatmap of the mitochondrial gene sets (leaf of the database tree) or gene set groups (section of the database tree).
mitoTreeHeatmap( data, database = "MitoCarta", sections = FALSE, samples = NULL, labelNames = "sections", ... )mitoTreeHeatmap( data, database = "MitoCarta", sections = FALSE, samples = NULL, labelNames = "sections", ... )
data |
matrix or data.frame with samples in columns and mitochondrial gene sets in rows. |
database |
character string saying the database used for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP". |
sections |
logical. Either to keep the aggregated gene set categories or the specific gene sets. Default is FALSE. |
samples |
character vector with the names of samples to be plotted. Otherwise all samples are plotted. |
labelNames |
character string that says to plot either the names of "sections" or "leaves". |
... |
other arguments passed on to the |
A ggplot object.
MClist <- getGeneSets() n <- length(names(MClist)) * 5 rmatrix <- matrix(rnorm(n, 0), ncol = 5) rownames(rmatrix) <- names(MClist) colnames(rmatrix) <- paste0("Sample_", seq_len(5)) mitoTreeHeatmap(data = rmatrix, database = "MitoCarta")MClist <- getGeneSets() n <- length(names(MClist)) * 5 rmatrix <- matrix(rnorm(n, 0), ncol = 5) rownames(rmatrix) <- names(MClist) colnames(rmatrix) <- paste0("Sample_", seq_len(5)) mitoTreeHeatmap(data = rmatrix, database = "MitoCarta")
A circular dotplot of the mitochondrial enrichment results.
mitoTreePoint( data, database = "MitoCarta", pvalCutoff = 0.05, labsize = 3, max_point_size = 4, color = "p.adjust" )mitoTreePoint( data, database = "MitoCarta", pvalCutoff = 0.05, labsize = 3, max_point_size = 4, color = "p.adjust" )
data |
named list of the result from enrichMito or gseaMito. |
database |
character string saying the database to use for the analysis. Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP". |
pvalCutoff |
pvalue cutoff to select enriched gene sets |
labsize |
label size |
max_point_size |
max point size |
color |
variable used to color enriched terms, e.g. 'pvalue', 'p.adjust' or 'NES'. |
A ggplot object.
data(ovse)data(ovse)
This is an example dataset containing gene expression values (in normalized
counts) of 40 ovarian cancer (OVC) patients extracted
from the Cancer Genome Atlas (TCGA) database.
This dataset should be used only with example purpose.
RNA sequencing OVC data were retrieved using
curatedTCGAData package. Data were then
normalized with the betweenLaneNormalization function.
To lighten the dataset, the consensusOVSign
function was computed, which return 4 different scores, one for each OVC
subtype (Chen et al, 2018, Clinical Cancer Research) and the 10 samples
with the highest scores were selected for each subgroup.
Further, only the mitochondrial genes included in mitology were kept.
Finally, the log fold change of the IMR versus the PRO samples were computed.
Further details in mitology/inst/scripts/howToGenerateOvse.Rmd.
data(ovse)data(ovse)
An object of class SummarizedExperiment with 2388 rows and 40 columns.